@@ -12,6 +12,7 @@ def load_configs(path):
             file_path = ('{}/{}'.format(path,file))
             configs.append(dotenv_values(dotenv_path=file_path))
     except FileNotFoundError:
-        sys.exit('Invalid path: {}'.format(path))
+        print('Invalid path: {}'.format(path))
+        sys.exit(0)
 
     return configs
